import { Agile, Collection, CollectionKey, GroupKey, ItemKey, Persistent, StorageKey } from "../internal";
export declare class CollectionPersistent<DataType = any> extends Persistent {
    collection: () => Collection;
    private defaultGroupSideEffectKey;
    static storageItemKeyPattern: string;
    static storageGroupKeyPattern: string;
    /**
     * @internal
     * Collection Persist Manager - Handles permanent storing of Collection Value
     * @param agileInstance - An instance of Agile
     * @param collection - Collection that gets stored
     * @param key - Key of Storage property
     */
    constructor(agileInstance: Agile, collection: Collection<DataType>, key?: StorageKey);
    set key(value: StorageKey);
    get key(): StorageKey;
    /**
     * @public
     * Sets Key/Name of Persistent
     * @param value - New Key/Name of Persistent
     */
    setKey(value: StorageKey): Promise<void>;
    /**
     * @internal
     * Loads Value from Storage
     * @return Success?
     */
    loadValue(): Promise<boolean>;
    /**
     * @internal
     * Saves/Updates Value in Storage
     * @return Success?
     */
    updateValue(): Promise<boolean>;
    /**
     * @internal
     * Removes Value form Storage
     * @return Success?
     */
    removeValue(): Promise<boolean>;
    /**
     * @internal
     * Validates Storage Key
     * @param key - Key that gets validated
     */
    validateKey(key?: StorageKey): StorageKey | null;
    /**
     * @internal
     * Rebuilds Storage depending on Group
     * @param group - Group
     */
    private rebuildStorageSideEffect;
    /**
     * @internal
     * Build Item StorageKey with Collection Persist Pattern
     * @param itemKey - Key of Item
     * @param collectionKey - Key of Collection
     */
    static getItemStorageKey(itemKey?: ItemKey, collectionKey?: CollectionKey): string;
    /**
     * @internal
     * Build Group StorageKey with Collection Persist Pattern
     * @param groupKey - Key of Group
     * @param collectionKey - Key of Collection
     */
    static getGroupStorageKey(groupKey?: GroupKey, collectionKey?: CollectionKey): string;
}
