"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Item = void 0;
const internal_1 = require("../internal");
class Item extends internal_1.State {
    /**
     * @public
     * Item of Collection
     * @param collection - Collection to which the Item belongs
     * @param data - Data that the Item holds
     */
    constructor(collection, data) {
        var _a;
        super(collection.agileInstance(), data);
        this.collection = () => collection;
        // Setting primaryKey of Data to Key/Name of Item
        this.key = data[((_a = collection.config) === null || _a === void 0 ? void 0 : _a.primaryKey) || "id"];
    }
    /**
     * @public
     * Set Key/Name of Item
     */
    set key(value) {
        // Note can't use 'super.key' because of 'https://github.com/Microsoft/TypeScript/issues/338'
        this.setKey(value);
        if (!value)
            return;
        // Update rebuildGroupThatIncludePrimaryKey SideEffect
        this.removeSideEffect("rebuildGroup");
        this.addSideEffect("rebuildGroup", (properties) => this.collection().rebuildGroupsThatIncludeItemKey(value, properties));
    }
    /**
     * @public
     * Get Key/Name of Item
     */
    get key() {
        // Note can't use 'super.key' because of 'https://github.com/Microsoft/TypeScript/issues/338'
        // Can't remove this getter function.. because the setter function is set in this class -> Error if not setter and getter function set
        return this._key;
    }
}
exports.Item = Item;
