import { Collection, DefaultItem, Item, ItemKey, State } from "../internal";
export declare class Selector<DataType = DefaultItem> extends State<DataType | undefined> {
    collection: () => Collection<DataType>;
    item: Item<DataType> | undefined;
    _itemKey: ItemKey;
    /**
     * @public
     * Represents Item of Collection
     * @param collection - Collection that contains the Item
     * @param itemKey - ItemKey of Item that the Selector represents
     * @param config - Config
     */
    constructor(collection: Collection<DataType>, itemKey: ItemKey, config?: SelectorConfigInterface);
    /**
     * @public
     * Set ItemKey that the Selector represents
     */
    set itemKey(value: ItemKey);
    /**
     * @public
     * Get ItemKey that the Selector represents
     */
    get itemKey(): ItemKey;
    /**
     * @public
     * Select new ItemKey that the Selector will represents
     * @param itemKey - New ItemKey
     * @param config - Config
     */
    select(itemKey: ItemKey, config?: SelectConfigInterface): this;
    /**
     * @public
     * Rebuilds Selector
     * @param config - Config
     */
    rebuildSelector(config?: SelectConfigInterface): void;
}
export declare type SelectorKey = string | number;
/**
 * @param key - Key/Name of Selector
 */
export interface SelectorConfigInterface {
    key?: SelectorKey;
}
/**
 * @param background - If selecting a new Item happens in the background (-> not causing any rerender)
 * @param sideEffects - If Side Effects of Selector get executed
 */
export interface SelectConfigInterface {
    background?: boolean;
    sideEffects?: boolean;
}
