import { State, Agile, Observer, StorageKey, StatePersistentConfigInterface } from "../internal";
export declare class Computed<ComputedValueType = any> extends State<ComputedValueType> {
    agileInstance: () => Agile;
    computeFunction: () => ComputedValueType;
    deps: Array<Observer>;
    hardCodedDeps: Array<Observer>;
    /**
     * @public
     * Computed - Function that recomputes its value if a dependency changes
     * @param agileInstance - An instance of Agile
     * @param computeFunction - Function for computing value
     * @param deps - Hard coded dependencies of Computed Function
     */
    constructor(agileInstance: Agile, computeFunction: () => ComputedValueType, deps?: Array<Observer | State | Event>);
    /**
     * @public
     * Set Value of Computed
     */
    set value(value: ComputedValueType);
    /**
     * @public
     * Get Value of Computed
     */
    get value(): ComputedValueType;
    /**
     * @public
     * Recomputes Function Value
     * -> Calls ComputeFunction and updates Dependencies of it
     * @param config - Config
     */
    recompute(config?: RecomputeConfigInterface): void;
    /**
     * @public
     * Applies new compute Function to Computed
     * @param computeFunction - New Function for computing value
     * @param deps - Hard coded dependencies of Computed Function
     * @param config - Config
     */
    updateComputeFunction(computeFunction: () => ComputedValueType, deps?: Array<Observer | State | Event>, config?: RecomputeConfigInterface): void;
    /**
     * @internal
     * Computes Value and adds missing Dependencies to Computed
     */
    computeValue(): ComputedValueType;
    patch(): this;
    persist(keyOrConfig?: StorageKey | StatePersistentConfigInterface, config?: StatePersistentConfigInterface): this;
    invert(): this;
}
/**
 * @param background - If recomputing value happens in the background (-> not causing any rerender)
 * @param sideEffects - If Side Effects of Computed get executed
 */
export interface RecomputeConfigInterface {
    background?: boolean;
    sideEffects?: boolean;
}
