import { Agile, Observer, Job, ObserverKey, Event } from "../internal";
export declare class EventObserver<PayloadType = any> extends Observer {
    event: () => Event<PayloadType>;
    /**
     * @internal
     * Event Observer - Handles Event dependencies and ingests Event triggers into the Runtime
     * @param {Agile} agileInstance - An instance of Agile
     * @param {Event} event - Event
     * @param {Array<Observer>} deps - Initial Dependencies of the Event
     * @param {ObserverKey} key - Key/Name of Event Observer
     */
    constructor(agileInstance: Agile, event: Event<PayloadType>, deps?: Array<Observer>, key?: ObserverKey);
    /**
     * @internal
     * Triggers a rerender on Components which got subscribed by this Event
     */
    trigger(): void;
    /**
     * @internal
     * Performs Job from Runtime
     * @param job - Job that gets performed
     */
    perform(job: Job<this>): void;
}
