"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventObserver = void 0;
const internal_1 = require("../internal");
class EventObserver extends internal_1.Observer {
    /**
     * @internal
     * Event Observer - Handles Event dependencies and ingests Event triggers into the Runtime
     * @param {Agile} agileInstance - An instance of Agile
     * @param {Event} event - Event
     * @param {Array<Observer>} deps - Initial Dependencies of the Event
     * @param {ObserverKey} key - Key/Name of Event Observer
     */
    constructor(agileInstance, event, deps, key) {
        super(agileInstance, deps, key);
        this.event = () => event;
    }
    //=========================================================================================================
    // Ingest
    //=========================================================================================================
    /**
     * @internal
     * Triggers a rerender on Components which got subscribed by this Event
     */
    trigger() {
        this.agileInstance().runtime.ingest(this, {});
    }
    //=========================================================================================================
    // Perform
    //=========================================================================================================
    /**
     * @internal
     * Performs Job from Runtime
     * @param job - Job that gets performed
     */
    perform(job) {
        // Noting to perform
    }
}
exports.EventObserver = EventObserver;
