import { Agile, SubscriptionContainer, Observer, Job, JobConfigInterface } from "../internal";
export declare class Runtime {
    agileInstance: () => Agile;
    private currentJob;
    private jobQueue;
    private notReadyJobsToRerender;
    private jobsToRerender;
    trackObservers: boolean;
    foundObservers: Set<Observer>;
    /**
     * @internal
     * Runtime - Performs ingested Observers
     * @param agileInstance - An instance of Agile
     */
    constructor(agileInstance: Agile);
    /**
     * @internal
     * Ingests Observer into Runtime
     * -> Creates Job which will be performed by the Runtime
     * @param observer - Observer that gets performed by the Runtime
     * @param config - Config
     */
    ingest(observer: Observer, config: JobConfigInterface): void;
    /**
     * @internal
     * Performs Job and adds him to the rerender queue if necessary
     * @param job - Job that gets performed
     */
    private perform;
    /**
     * @internal
     * Updates/Rerenders all Subscribed Components of the Job (Observer)
     */
    private updateSubscribers;
    /**
     * @internal
     * Finds updated Key of SubscriptionContainer and adds it to 'changedObjectKeys'
     * @param subscriptionContainer - Object based SubscriptionContainer
     * @param job - Job that holds the SubscriptionContainer
     */
    handleObjectBasedSubscription(subscriptionContainer: SubscriptionContainer, job: Job): void;
    /**
     * @internal
     * Builds Object from 'changedObjectKeys' with new Values provided by Observers
     * @param subscriptionContainer - SubscriptionContainer from which the Object gets built
     */
    getObjectBasedProps(subscriptionContainer: SubscriptionContainer): {
        [key: string]: any;
    };
    /**
     * @internal
     * Returns tracked Observers and stops Runtime from tracking anymore Observers
     */
    getTrackedObservers(): Set<Observer>;
}
