import { Agile, StateKey, Job, SubscriptionContainer } from "../internal";
export declare type ObserverKey = string | number;
export declare class Observer<ValueType = any> {
    agileInstance: () => Agile;
    _key?: ObserverKey;
    deps: Set<Observer>;
    subs: Set<SubscriptionContainer>;
    value?: ValueType;
    /**
     * @internal
     * Observer - Handles subscriptions and dependencies of an Agile Class and is like an instance to the Runtime
     * @param agileInstance - An instance of Agile
     * @param value - Initial Value of Observer
     * @param deps - Initial Dependencies of Observer
     * @param key - Key/Name of Observer
     */
    constructor(agileInstance: Agile, deps?: Array<Observer>, key?: ObserverKey, value?: ValueType);
    /**
     * @internal
     * Set Key/Name of Observer
     */
    set key(value: StateKey | undefined);
    /**
     * @internal
     * Get Key/Name of Observer
     */
    get key(): StateKey | undefined;
    /**
     * @internal
     * Performs Job of Runtime
     * @param job - Job that gets performed
     */
    perform(job: Job): void;
    /**
     * @internal
     * Adds Dependency to Observer that will be ingested into the Runtime if this Observer changes
     * @param observer - Observer that will depend on this Observer
     */
    depend(observer: Observer): void;
    /**
     * @internal
     * Adds Subscription to Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets subscribed by this Observer
     */
    subscribe(subscriptionContainer: SubscriptionContainer): void;
    /**
     * @internal
     * Removes Subscription from Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets unsubscribed by this Observer
     */
    unsubscribe(subscriptionContainer: SubscriptionContainer): void;
}
