"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Observer = void 0;
class Observer {
    /**
     * @internal
     * Observer - Handles subscriptions and dependencies of an Agile Class and is like an instance to the Runtime
     * @param agileInstance - An instance of Agile
     * @param value - Initial Value of Observer
     * @param deps - Initial Dependencies of Observer
     * @param key - Key/Name of Observer
     */
    constructor(agileInstance, deps, key, value) {
        this.deps = new Set(); // Observers that depends on this Observer
        this.subs = new Set(); // SubscriptionContainers(Components) which this Observer has subscribed
        this.agileInstance = () => agileInstance;
        this._key = key;
        this.value = value;
        deps === null || deps === void 0 ? void 0 : deps.forEach((observer) => this.deps.add(observer));
    }
    /**
     * @internal
     * Set Key/Name of Observer
     */
    set key(value) {
        this._key = value;
    }
    /**
     * @internal
     * Get Key/Name of Observer
     */
    get key() {
        return this._key;
    }
    //=========================================================================================================
    // Perform
    //=========================================================================================================
    /**
     * @internal
     * Performs Job of Runtime
     * @param job - Job that gets performed
     */
    perform(job) {
        console.warn("Agile: Didn't set perform function in Observer ", this.key);
    }
    //=========================================================================================================
    // Depend
    //=========================================================================================================
    /**
     * @internal
     * Adds Dependency to Observer that will be ingested into the Runtime if this Observer changes
     * @param observer - Observer that will depend on this Observer
     */
    depend(observer) {
        if (!this.deps.has(observer))
            this.deps.add(observer);
    }
    //=========================================================================================================
    // Subscribe
    //=========================================================================================================
    /**
     * @internal
     * Adds Subscription to Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets subscribed by this Observer
     */
    subscribe(subscriptionContainer) {
        if (!this.subs.has(subscriptionContainer))
            this.subs.add(subscriptionContainer);
    }
    //=========================================================================================================
    // Unsubscribe
    //=========================================================================================================
    /**
     * @internal
     * Removes Subscription from Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets unsubscribed by this Observer
     */
    unsubscribe(subscriptionContainer) {
        if (this.subs.has(subscriptionContainer))
            this.subs.delete(subscriptionContainer);
    }
}
exports.Observer = Observer;
