import { Agile, Observer, State, Job, JobConfigInterface, ObserverKey } from "../internal";
export declare const internalIngestKey = "THIS_IS_AN_INTERNAL_KEY_FOR_INGESTING_INTERNAL_STUFF";
export declare class StateObserver<ValueType = any> extends Observer {
    state: () => State<ValueType>;
    nextStateValue: ValueType;
    /**
     * @internal
     * State Observer - Handles State changes, dependencies (-> Interface to Runtime)
     * @param agileInstance - An instance of Agile
     * @param state - State
     * @param deps - Initial Dependencies of State Observer
     * @param key - Key/Name of State Observer
     */
    constructor(agileInstance: Agile, state: State<ValueType>, deps?: Array<Observer>, key?: ObserverKey);
    /**
     * @internal
     * Ingests new State Value into Runtime and applies it to the State
     * @param newStateValue - New Value of the State
     * @param config - Config
     */
    ingest(newStateValue?: ValueType | InternalIngestKeyType, config?: StateJobConfigInterface): void;
    /**
     * @internal
     * Performs Job from Runtime
     * @param job - Job that gets performed
     */
    perform(job: Job<this>): void;
    /**
     * @internal
     * SideEffects of Perform Function
     * @param job - Job whose SideEffects gets executed
     */
    private sideEffects;
}
export declare type InternalIngestKeyType = "THIS_IS_AN_INTERNAL_KEY_FOR_INGESTING_INTERNAL_STUFF";
/**
 * @param forceRerender - Force rerender no matter what happens
 */
export interface StateJobConfigInterface extends JobConfigInterface {
    forceRerender?: boolean;
}
