import { Agile, Persistent, State, StorageKey } from "../internal";
export declare class StatePersistent<ValueType = any> extends Persistent {
    state: () => State;
    /**
     * @internal
     * State Persist Manager - Handles permanent storing of State Value
     * @param agileInstance - An instance of Agile
     * @param state - State that gets stored
     * @param key - Key of Storage property
     * @param config - Config
     */
    constructor(agileInstance: Agile, state: State<ValueType>, key?: StorageKey, config?: StatePersistentConfigInterface);
    set key(value: StorageKey);
    get key(): StorageKey;
    /**
     * @public
     * Sets Key/Name of Persistent
     * @param value - New Key/Name of Persistent
     */
    setKey(value: StorageKey): Promise<void>;
    /**
     * @internal
     * Loads Value from Storage
     * @return Success?
     */
    loadValue(): Promise<boolean>;
    /**
     * @internal
     * Saves/Updates Value in Storage
     * @return Success?
     */
    updateValue(): Promise<boolean>;
    /**
     * @internal
     * Removes Value form Storage
     * @return Success?
     */
    removeValue(): Promise<boolean>;
    /**
     * @internal
     * Validates Storage Key
     * @param key - Key that gets validated
     */
    validateKey(key?: StorageKey): StorageKey | null;
}
/**
 * @param instantiate - If Persistent gets instantiated
 */
export interface StatePersistentConfigInterface {
    instantiate?: boolean;
}
