import { Persistent } from "../internal";
export declare class Storage {
    storageReady: boolean;
    storageType: StorageType;
    config: StorageConfigInterface;
    persistentInstances: Set<Persistent>;
    /**
     * @public
     * Storage - Interface for storing Items permanently
     * @param storageConfig - Config
     */
    constructor(storageConfig: StorageConfigInterface);
    /**
     * @internal
     * Instantiates Local Storage
     */
    private instantiateLocalStorage;
    /**
     * @internal
     * Instantiates Custom Storage
     */
    private instantiateCustomStorage;
    /**
     * @public
     * Gets value at provided Key
     * @param key - Key of Storage property
     */
    get<GetType = any>(key: StorageKey): GetType | Promise<GetType> | undefined;
    /**
     * @internal
     * Gets value at provided Key (async)
     * @param key - Key of Storage property
     */
    private asyncGet;
    /**
     * @public
     * Saves/Updates value at provided Key
     * @param key - Key of Storage property
     * @param value - new Value that gets set
     */
    set(key: StorageKey, value: any): void;
    /**
     * @public
     * Removes value at provided Key
     * @param key - Key of Storage property
     */
    remove(key: StorageKey): void;
    /**
     * @internal
     * Creates Storage Key from provided key
     * @param key - Key that gets converted into a Storage Key
     */
    private getStorageKey;
    /**
     * @internal
     * Checks if localStorage is available in this Environment
     */
    static localStorageAvailable(): boolean;
}
export declare type StorageKey = string | number;
export declare type StorageType = "localStorage" | "custom";
/**
 * @param async - If its an async storage
 * @param prefix - Prefix of Storage Property
 * @param methods - Storage methods like (get, set, remove)
 * @param methods.get - Get Method of Storage (gets items from storage)
 * @param methods.set - Set Method of Storage (saves/updates items in storage)
 * @param methods.remove - Remove Methods of Storage (removes items from storage)
 */
export interface StorageConfigInterface {
    async?: boolean;
    prefix?: string;
    methods?: {
        get: (key: string) => any;
        set: (key: string, value: any) => void;
        remove: (key: string) => void;
    };
}
