import { Agile, StorageKey } from "../internal";
export declare class Persistent<ValueType = any> {
    agileInstance: () => Agile;
    _key: StorageKey;
    ready: boolean;
    /**
     * @internal
     * Persistent - Handles storing of Agile Instances
     * @param agileInstance - An instance of Agile
     */
    constructor(agileInstance: Agile);
    /**
     * @internal
     * Set Key/Name of Persistent
     */
    set key(value: StorageKey);
    /**
     * @internal
     * Get Key/Name of Persistent
     */
    get key(): StorageKey;
    /**
     * @internal
     * Inits Persistent (this class)
     * -> Sometimes this class needs to be instantiated after some properties have been set in extended class
     * @param key - Key of Storage property
     */
    instantiatePersistent(key?: StorageKey): Promise<boolean>;
    /**
     * @internal
     * Loads/Saves Storage Value for the first Time
     * @param key -  Key of Storage property
     */
    initialLoading(key: StorageKey): Promise<void>;
    /**
     * @internal
     * Loads Value from Storage
     * @return Success?
     */
    loadValue(): Promise<boolean>;
    /**
     * @internal
     * Saves/Updates Value in Storage
     * @return Success?
     */
    updateValue(): Promise<boolean>;
    /**
     * @internal
     * Removes Value form Storage
     * @return Success?
     */
    removeValue(): Promise<boolean>;
    /**
     * @internal
     * Validates Storage Key
     * @param key - Key that gets validated
     */
    validateKey(key?: StorageKey): StorageKey | null;
}
