"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Persistent = void 0;
class Persistent {
    /**
     * @internal
     * Persistent - Handles storing of Agile Instances
     * @param agileInstance - An instance of Agile
     */
    constructor(agileInstance) {
        this._key = "unknown";
        this.ready = false;
        this.agileInstance = () => agileInstance;
    }
    /**
     * @internal
     * Set Key/Name of Persistent
     */
    set key(value) {
        this._key = value;
    }
    /**
     * @internal
     * Get Key/Name of Persistent
     */
    get key() {
        return this._key;
    }
    //=========================================================================================================
    // Init Persistent
    //=========================================================================================================
    /**
     * @internal
     * Inits Persistent (this class)
     * -> Sometimes this class needs to be instantiated after some properties have been set in extended class
     * @param key - Key of Storage property
     */
    instantiatePersistent(key) {
        return __awaiter(this, void 0, void 0, function* () {
            // Validate Key
            const finalKey = this.validateKey(key);
            if (!finalKey) {
                console.error("Agile: No persist Key found!");
                return false;
            }
            this._key = finalKey;
            this.agileInstance().storage.persistentInstances.add(this);
            this.ready = true;
            // Load/Store persisted Value/s for the first Time
            yield this.initialLoading(finalKey);
            return true;
        });
    }
    //=========================================================================================================
    // Initial Loading
    //=========================================================================================================
    /**
     * @internal
     * Loads/Saves Storage Value for the first Time
     * @param key -  Key of Storage property
     */
    initialLoading(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const success = yield this.loadValue();
            if (!success)
                yield this.updateValue();
        });
    }
    //=========================================================================================================
    // Load Value
    //=========================================================================================================
    /**
     * @internal
     * Loads Value from Storage
     * @return Success?
     */
    loadValue() {
        return __awaiter(this, void 0, void 0, function* () {
            console.warn(`Agile: Didn't set loadValue function in Persistent '${this.key}'`);
            return false;
        });
    }
    //=========================================================================================================
    // Update Value
    //=========================================================================================================
    /**
     * @internal
     * Saves/Updates Value in Storage
     * @return Success?
     */
    updateValue() {
        return __awaiter(this, void 0, void 0, function* () {
            console.warn(`Agile: Didn't set setValue function in Persistent '${this.key}'`);
            return false;
        });
    }
    //=========================================================================================================
    // Remove Value
    //=========================================================================================================
    /**
     * @internal
     * Removes Value form Storage
     * @return Success?
     */
    removeValue() {
        return __awaiter(this, void 0, void 0, function* () {
            console.warn(`Agile: Didn't set removeValue function in Persistent '${this.key}'`);
            return false;
        });
    }
    //=========================================================================================================
    // Validate Key
    //=========================================================================================================
    /**
     * @internal
     * Validates Storage Key
     * @param key - Key that gets validated
     */
    validateKey(key) {
        console.warn(`Agile: Didn't set validateKey function in Persistent '${this.key}'`);
        return null;
    }
}
exports.Persistent = Persistent;
