import { Agile } from "./internal";
/**
 * @internal
 * Creates a fresh copy of an Array/Object
 * @param value - Array/Object that gets copied
 */
export declare function copy<T = any>(value: T): T;
export declare function copy<T extends Array<T>>(value: T): T[];
/**
 * @internal
 * Checks if an value is a valid Object
 * https://stackoverflow.com/questions/12996871/why-does-typeof-array-with-objects-return-object-and-not-array
 * @param value - Value that is tested for its correctness
 */
export declare function isValidObject(value: any): boolean;
/**
 * @internal
 * Transforms Item/s to an Item Array
 * @param items - Item/s that gets transformed to an Array
 */
export declare function normalizeArray<DataType = any>(items?: DataType | Array<DataType>): Array<DataType>;
/**
 * @internal
 * Tries to get an AgileInstance from provided instance
 * If no agileInstance found it returns the global AgileInstance
 * @param instance - Instance that might hold an AgileInstance
 */
export declare function getAgileInstance(instance: any): Agile | undefined;
/**
 * @internal
 * Checks if value is a function
 * @param value - Value that gets tested if its a function
 */
export declare function isFunction(value: any): boolean;
/**
 * @internal
 * Checks if value is an async function
 * @param value - Value that gets tested if its an async function
 */
export declare function isAsyncFunction(value: any): boolean;
/**
 * @internal
 * Checks the correctness of an url
 * Resource: https://stackoverflow.com/questions/5717093/check-if-a-javascript-string-is-a-url
 * @param url - Url that gets tested for its correctness
 */
export declare function isValidUrl(url: string): boolean;
/**
 * @internal
 * Checks if value is valid JsonString
 * @param value - Value that gets checked
 */
export declare function isJsonString(value: any): boolean;
/**
 * @internal
 * Merges default values/properties into config object
 * @param config - Config object that receives default values
 * @param defaults - Default values object that gets merged into config object
 */
export declare function defineConfig<ConfigInterface = Object>(config: ConfigInterface, defaults: Object): ConfigInterface;
/**
 * @internal
 * @param addNewProperties - Adds new properties to source Object
 */
export interface FlatMergeConfigInterface {
    addNewProperties?: boolean;
}
/**
 * @internal
 * Merges items into object, be aware that the merge will only happen at the top level of the object
 * @param source - Source object
 * @param changes - Changes that get merged into the source object
 * @param config - Config
 */
export declare function flatMerge<DataType = Object>(source: DataType, changes: Object, config?: FlatMergeConfigInterface): DataType;
/**
 * @internal
 * Check if two values are equal
 * @param value1 - First Value
 * @param value2 - Second Value
 */
export declare function equal(value1: any, value2: any): boolean;
/**
 * @internal
 * Checks if two values aren't equal
 * @param value1 - First Value
 * @param value2 - Second Value
 */
export declare function notEqual(value1: any, value2: any): boolean;
/**
 * @internal
 * Generates random Id
 * @param length - Length of generated Id
 */
export declare function generateId(length?: number): string;
/**
 * @internal
 * Clones a Class
 * @param instance - Instance of Class you want to clone
 */
export declare function clone<T>(instance: T): T;
/**
 * @internal
 * Binds Instance Global
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/globalThis
 * @param key - Key of Instance
 * @param instance - Instance which becomes globally accessible (globalThis.key)
 */
export declare function globalBind(key: string, instance: any): void;
